@@ -1,6 +1,6 @@
 #' @S3method plot prof
 
-plot.prof <- function(x, y = NULL, ...){
+plot.prof <- function(x, ...){
 	dat0 <- x$pattern.level
 	dim <- ncol(dat0)
 	dat1 <- as.data.frame(dat0[,c(dim/2,dim)])
